# Changelog

## dev

- Improve documentation
- Add more test function

## 0.1.0

### ADD

- add comment note api
- add delete note comment api
- add comment user api
- add follow user api
- add unfollow user api
- add collect note api
- add uncollect note api
- add like note api
- add like comment api
- add dislike note api
- add dislike comment api
- add get qrcode api
- add check qrcode api
- add save files from note id api

## 0.0.4

### ADD

- add x-s 、search_id signature
- add get note by id api
- add get self info api
- add get user info api
- add get home feed api
- add get note by keyword api
- add get user notes api

## 0.0.3

### ADD

- add pypi, doc, test ci actions

## 0.0.2

### ADD

- add Sphinx Doc

## 0.0.1

### ADD

- Structuring project (base on [Structuring Your Project](https://docs.python-guide.org/writing/structure/))
